pub struct FluentText<T: FluentMessage + Clone> {
pub value: T,
}Expand description
A Bevy component that holds localized text content.
FluentText is a generic component that wraps any type implementing
FluentMessage and Clone. It’s designed to work with the es-fluent
localization system in Bevy applications.
When its message type is registered through #[derive(BevyFluentText)] or
manual registration, FluentText updates Bevy Text components when the
application locale changes.
Examples
ⓘ
use bevy::prelude::*;
use es_fluent::EsFluent;
use es_fluent_manager_bevy::{BevyFluentText, FluentText};
// The message key is derived from the struct name: "simple-message"
#[derive(BevyFluentText, Clone, EsFluent)]
struct SimpleMessage {
name: String,
}
fn setup_text(mut commands: Commands) {
let content = SimpleMessage { name: "World".to_string() };
commands.spawn((FluentText::new(content), Text::new("")));
}Fields
value: TThe localized text content.
Implementations
Sourceimpl<T: FluentMessage + Clone> FluentText<T>
impl<T: FluentMessage + Clone> FluentText<T>
Sourcepub fn new(value: T) -> Self
pub fn new(value: T) -> Self
Creates a new FluentText component with the given value.
Arguments
value- The text content that implementsFluentMessageandClone
Examples
Create a FluentText component with a simple string message:
use es_fluent_manager_bevy::FluentText;
use es_fluent::EsFluent;
// The message key is derived from the struct name: "message"
#[derive(Clone, EsFluent)]
struct Message {
content: String,
}
let text = FluentText::new(Message { content: "Hello".to_string() });Trait Implementations
Sourceimpl<T: Clone + FluentMessage + Clone> Clone for FluentText<T>
impl<T: Clone + FluentMessage + Clone> Clone for FluentText<T>
Sourceimpl<T: FluentMessage + Clone> Component for FluentText<T>
impl<T: FluentMessage + Clone> Component for FluentText<T>
Sourceconst STORAGE_TYPE: StorageType = ::bevy::ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = ::bevy::ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have
Component<Mutability = Mutable>,
while immutable components will instead have Component<Mutability = Immutable>. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
Returns
ComponentRelationshipAccessor required for working with relationships in dynamic contexts. Read moreSourcefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreAuto Trait Implementations
impl<T> Freeze for FluentText<T>where
T: Freeze,
impl<T> RefUnwindSafe for FluentText<T>where
T: RefUnwindSafe,
impl<T> Send for FluentText<T>where
T: Send,
impl<T> Sync for FluentText<T>where
T: Sync,
impl<T> Unpin for FluentText<T>where
T: Unpin,
impl<T> UnsafeUnpin for FluentText<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for FluentText<T>where
T: UnwindSafe,